@@ -152,10 +152,13 @@ class MiniRPACore:
             if not need_replace:
                 if self.file_name_suffix and file_name:
                     file_name = f'{split_file_name}_{self.file_name_suffix}.xlsx'
+                    file_name = self.replace_variables_in_string(file_name)
                 elif not self.file_name_suffix and file_name:
                     file_name = f'{split_file_name}.xlsx'
+                    file_name = self.replace_variables_in_string(file_name)
                 elif not file_name and self.file_name_suffix:
                     file_name = f'{self.file_name_suffix}.xlsx'
+                    file_name = self.replace_variables_in_string(file_name)
                 else:
                     file_name = None
             else:
@@ -171,8 +174,16 @@ class MiniRPACore:
         Args:
             target_string(str): This is the target string
         """
-        company_code = self.common_field_dict.get('company_code', '')
-        entity_name = self.common_field_dict.get('entity_name', '')
+        # company_code = self.common_field_dict.get('company_code', '')
+        company_code_list = self.common_field_dict.get('company_code', '').strip().replace('，', ',').split(',')
+        company_code_list = [company_code.strip() for company_code in company_code_list if company_code.strip()]
+        company_code = company_code_list[0] if company_code_list else ''
+
+        # entity_name = self.common_field_dict.get('entity_name', '')
+        entity_name_list = self.common_field_dict.get('entity_name', '').strip().replace('，', ',').split(',')
+        entity_name_list = [entity_name.strip() for entity_name in entity_name_list if entity_name.strip()]
+        entity_name = entity_name_list[0] if entity_name_list else ''
+
         target_string = (target_string
                          .replace('SYYYY', str(self.from_period_date.year))
                          .replace('SMM', str(self.from_period_date.month).rjust(2, '0'))
