@@ -153,6 +153,9 @@ class MiniRpaManager(MiniRpaFunction):
                 elif function_name == 'input_query_field_multiple_values':
                     sap_automation.input_query_field_multiple_values(int(sap_operation_dict['field_button_index']), int(sap_operation_dict['tab_index']), field_values,
                                                                      second_field_values)
+                elif function_name == 'input_field_multiple_values_with_field_label':
+                    sap_automation.input_field_multiple_values_with_field_label(sap_operation_dict['field_label'], int(sap_operation_dict['tab_index']), field_values,
+                                                                                second_field_values)
                 elif function_name == 'input_field_single_value':
                     sap_automation.input_field_single_value(sap_operation_dict['field_title'], int(sap_operation_dict['field_index']), sap_operation_dict['field_value'],
                                                             is_enter,
@@ -662,23 +665,6 @@ class MiniRpaManager(MiniRpaFunction):
                 deletion_keyword = deletion_keyword if deletion_keyword else ''
                 self.clear_existed_files_by_keywords(report_save_path, deletion_keyword)
             elif delivery_type == 'copy_file_cross_public_folders':
-                # from_server_name = self.delivery_dict.get('from_server_name', '')
-                # from_share_name = self.delivery_dict.get('from_share_name', '')
-                # from_folder_path = self.replace_variables_in_string(self.delivery_dict.get('from_folder_path', ''))
-                # from_file_name = self.prepare_file_name(self.delivery_dict.get('from_file_name', ''))
-                #
-                # update_server_name = self.delivery_dict.get('update_server_name', '')
-                # update_share_name = self.delivery_dict.get('update_share_name', '')
-                # update_folder_path = self.replace_variables_in_string(self.delivery_dict.get('update_folder_path', ''))
-                # update_file_name = self.prepare_file_name(self.delivery_dict.get('update_file_name', ''))
-                #
-                # from_server_name = from_server_name if from_server_name else self.server_name
-                # from_share_name = from_share_name if from_share_name else self.share_name
-                # from_folder_path = from_folder_path if from_folder_path else self.report_save_path
-                # update_server_name = update_server_name if update_server_name else self.server_name
-                # update_share_name = update_share_name if update_share_name else self.share_name
-                # update_folder_path = update_folder_path if update_folder_path else self.report_save_path
-
                 self.copy_file_cross_public_folders(from_server_name, from_share_name, from_folder_path, from_file_name, update_server_name, update_share_name, update_folder_path,
                                                     update_file_name)
 
@@ -687,18 +673,13 @@ class MiniRpaManager(MiniRpaFunction):
                 api_credential = self.delivery_dict.get('api_credential', '')
                 self.trigger_python_bot_task(bot_url, api_credential)
 
-            elif delivery_type == 'upload_file_to_sharepoint':
-                # from_folder_path = self.replace_variables_in_string(self.delivery_dict.get('from_folder_path', ''))
-                # from_file_name = self.prepare_file_name(self.delivery_dict.get('from_file_name', ''))
-                sharepoint_site_url = self.delivery_dict.get('sharepoint_site_url', '')
-                sharepoint_folder_url = self.delivery_dict.get('sharepoint_folder_url', '')
-                sharepoint_file_name = self.prepare_file_name(self.delivery_dict.get('sharepoint_file_name', ''))
-                self.upload_file_to_sharepoint(from_folder_path, from_file_name, sharepoint_site_url, sharepoint_folder_url, sharepoint_file_name)
             elif delivery_type == 'batch_copy_files_within_public_folders':
                 file_key_word = self.delivery_dict.get('file_key_word', '')
                 copy_mode = self.delivery_dict.get('copy_mode', 'contain_key_word')
+                deep_search = self.delivery_dict.get('deep_search', False)
+                deep_search = deep_search if deep_search else False
                 self.batch_copy_files_within_public_folders(from_server_name, from_share_name, from_folder_path, file_key_word, update_server_name, update_share_name,
-                                                            update_folder_path, copy_mode)
+                                                            update_folder_path, copy_mode, deep_search=deep_search, smb_client=None)
 
         if self.process_database:
             database_config_dict = {
