@@ -199,6 +199,27 @@ class MiniRpaSapAutomation:
 
         self.web_rpa.input_multiple_selection_with_index(field_values, field_button_index, tab_index, clear_section_data=True)
 
+    def input_field_multiple_values_with_field_label(self, field_label, tab_index, field_values, second_field_values):
+        """ This function is used to input multiple field values in SE16.
+
+        Args:
+            field_label(str): This is the label of field name
+            tab_index(int): This is the index of tab. e.g. 1,2
+            field_values(list): This is the list of values
+            second_field_values(list): This is the list of second values
+        """
+        second_field_values = [field_value for field_value in second_field_values if str(field_value).strip()]
+        if second_field_values and tab_index in [2, 4]:
+            temp_field_values = []
+            for field_index, field_value in enumerate(field_values):
+                try:
+                    temp_field_values.append(f"{field_value}\t{second_field_values[field_index]}")
+                except IndexError:
+                    temp_field_values.append(f"{field_value}\t ")
+            field_values = temp_field_values
+
+        self.web_rpa.input_multiple_selection_with_field_label(field_values, field_label, tab_index, clear_section_data=True)
+
     def input_query_field_multiple_values(self, field_button_index, tab_index, field_values, second_field_values):
         """ This function is used to input multiple field values in SE16.
 
@@ -939,26 +960,31 @@ class MiniRpaSapAutomation:
         remote_file_path = upload_folder_path + os.sep + upload_file_name
         local_file_path = self.web_rpa.save_folder_path + os.sep + upload_file_name
 
-        smb_copy_file_remote_to_local(self.user_name, self.user_password, self.server_name, self.share_name, local_file_path, remote_file_path, self.port)
-        screenshot_path_list = self.web_rpa.upload_files_in_popup_window(local_file_path, window_name, True)
-        sleep(2)
-        self.wait_importing_file_dialog_invisibility()
-        sleep(1)
+        is_remote_file_exist, _ = smb_check_file_exist(self.user_name, self.user_password, self.server_name, self.share_name, remote_file_path, self.port)
+        if is_remote_file_exist:
+            smb_copy_file_remote_to_local(self.user_name, self.user_password, self.server_name, self.share_name, local_file_path, remote_file_path, self.port)
+            screenshot_path_list = self.web_rpa.upload_files_in_popup_window(local_file_path, window_name, True)
+            sleep(2)
+            self.wait_importing_file_dialog_invisibility()
+            sleep(1)
 
-        remote_screenshot_folder_path = self.report_save_path + os.sep + 'Screenshots'
-        is_folder_exist = smb_check_folder_exist(self.user_name, self.user_password, self.server_name, self.share_name, remote_screenshot_folder_path, self.port)
-        if not is_folder_exist:
-            smb_create_folder(self.user_name, self.user_password, self.server_name, self.share_name, remote_screenshot_folder_path)
-
-        if self.browser_screenshot_tag:
-            remote_screenshot_folder_path = remote_screenshot_folder_path + os.sep + self.browser_screenshot_tag
-            is_folder_exist = smb_check_folder_exist(self.user_name, self.user_password, self.server_name, self.share_name, remote_screenshot_folder_path)
+            remote_screenshot_folder_path = self.report_save_path + os.sep + 'Screenshots'
+            is_folder_exist = smb_check_folder_exist(self.user_name, self.user_password, self.server_name, self.share_name, remote_screenshot_folder_path, self.port)
             if not is_folder_exist:
                 smb_create_folder(self.user_name, self.user_password, self.server_name, self.share_name, remote_screenshot_folder_path)
 
-        for screenshot_path in screenshot_path_list:
-            remote_file_path = remote_screenshot_folder_path + os.sep + screenshot_path.split(os.sep)[-1]
-            smb_copy_file_local_to_remote(self.user_name, self.user_password, self.server_name, self.share_name, screenshot_path, remote_file_path, self.port)
+            if self.browser_screenshot_tag:
+                remote_screenshot_folder_path = remote_screenshot_folder_path + os.sep + self.browser_screenshot_tag
+                is_folder_exist = smb_check_folder_exist(self.user_name, self.user_password, self.server_name, self.share_name, remote_screenshot_folder_path)
+                if not is_folder_exist:
+                    smb_create_folder(self.user_name, self.user_password, self.server_name, self.share_name, remote_screenshot_folder_path)
+
+            for screenshot_path in screenshot_path_list:
+                remote_file_path = remote_screenshot_folder_path + os.sep + screenshot_path.split(os.sep)[-1]
+                smb_copy_file_local_to_remote(self.user_name, self.user_password, self.server_name, self.share_name, screenshot_path, remote_file_path, self.port)
+        else:
+            print(f'Cannot find file: {upload_file_name} in folder: {upload_folder_path}')
+            self.skip_download_process = True
 
     def wait_importing_file_dialog_invisibility(self):
         """ This function is used to wait importing file dialog invisibility.
